@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
+ * Free Software Foundation; either version 3 of the License, or (at your
  * option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -27,6 +27,26 @@
 #include "gucharmap.h"
 #include "gucharmap-private.h"
 
+static int
+compare_iters (GtkTreeModel *model,
+               GtkTreeIter *iter_a,
+               GtkTreeIter *iter_b,
+               gpointer user_data)
+{
+  char *label_a, *label_b;
+  int ret;
+
+  gtk_tree_model_get (model, iter_a, GUCHARMAP_CHAPTERS_MODEL_COLUMN_LABEL, &label_a, -1);
+  gtk_tree_model_get (model, iter_b, GUCHARMAP_CHAPTERS_MODEL_COLUMN_LABEL, &label_b, -1);
+
+  ret = g_utf8_collate (label_a, label_b);
+
+  g_free (label_a);
+  g_free (label_b);
+
+  return ret;
+}
+
 static void
 gucharmap_script_chapters_model_init (GucharmapScriptChaptersModel *model)
 {
@@ -51,6 +71,11 @@ gucharmap_script_chapters_model_init (GucharmapScriptChaptersModel *model)
                           -1);
     }
   g_free (unicode_scripts);
+
+  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
+                                   GUCHARMAP_CHAPTERS_MODEL_COLUMN_LABEL,
+                                   (GtkTreeIterCompareFunc) compare_iters,
+                                   NULL, NULL);
 }
 
 static GucharmapCodepointList *
